from .params import get_profile


def validate_resource(resource: str):
    try:
        get_profile(resource)
        return True
    except KeyError:
        return False


def validate_bool_str(bool_str: str):
    return bool_str.lower() in {"true", "false"}



from typing import Any, Callable

from sym.shared.cli.errors import get_active_env_vars
from sym.shared.cli.helpers.sym_group import AutoTagCommand as SharedAutoTagCommand
from sym.shared.cli.helpers.sym_group import SymGroup as SharedSymGroup

from ..saml_clients.chooser import choose_saml_client


class AutoTagCommand(SharedAutoTagCommand):
    def parse_args(self, ctx, args):
        """
        To work around https://github.com/pallets/click/issues/714, we are doing a trick:
        we always parse a resource *option* from the root command, and then we sometimes
        rewrite the args passed to a child command before parsing the resource *argument*.
        """
        if (
            self.params
            and (resource := ctx.parent.params.get("resource"))
            and self.params[0].name == "resource"
            and (
                not args
                or not choose_saml_client(
                    ctx.parent.params["saml_client_name"]
                ).validate_resource(args[0])
            )
        ):
            args = [resource] + args
        return super().parse_args(ctx, args)

    def format_epilog(self, ctx, formatter):
        if not self.epilog:
            formatter.write(get_active_env_vars())
        super().format_epilog(ctx, formatter)


class SymGroup(SharedSymGroup):
    def command(
        self, *args: Any, cls=None, **kwargs: Any
    ) -> Callable[[Callable[..., Any]], AutoTagCommand]:
        return super().command(*args, **kwargs, cls=cls or AutoTagCommand)  # type: ignore



import shlex
import subprocess
import sys
from functools import wraps
from subprocess import PIPE, CalledProcessError
from typing import Any, Callable, Iterator, Optional, Sequence, TypeVar, cast

import click
from sym.shared.cli.decorators import (  # noqa
    command_require_bins,
    require_bins,
    retry,
    setup_segment,
    setup_sentry,
)
from sym.shared.cli.errors import (
    CliError,
    ErrorPatterns,
    FailedSubprocessError,
    SuppressedError,
    raise_if_match,
)
from sym.shared.cli.helpers.keywords_to_options import Argument, keywords_to_options
from sym.shared.cli.helpers.tee import Tee

from sym.cli.helpers.config import Config
from sym.cli.helpers.global_options import GlobalOptions
from sym.cli.saml_clients.saml_client_factory import SAMLClientFactory

F = TypeVar("F", bound=Callable[..., Any])


def run_subprocess(
    func: Callable[..., Iterator[Sequence[Argument]]]
) -> Callable[..., Optional[Sequence[Optional[str]]]]:
    @wraps(func)
    def impl(
        *args: Any,
        censor_: bool = False,
        capture_output_: bool = False,
        silence_stderr_: bool = True,
        input_: str = None,
        run_subprocess_options_: Optional[GlobalOptions] = None,
        **kwargs: Any,
    ) -> Optional[Sequence[Optional[str]]]:

        options = run_subprocess_options_
        if not options:
            # Ideally we will never need to access click at this level and
            # will instead always pass in options. This is for backward
            # compatibility as we refactor.
            options = click.get_current_context().find_object(GlobalOptions)

        outputs = []
        tee = bool(options.log_dir) and not censor_

        for command in func(*args, **kwargs):
            command = keywords_to_options(command)
            options.dprint(f"exec: {shlex.join(command)}\n")
            if tee:
                command = Tee.tee_command(options.log_dir, command)
            result = subprocess.run(
                command,
                check=True,
                capture_output=capture_output_,
                input=input_,
                stderr=None if (capture_output_ or not silence_stderr_) else PIPE,
                text=True,
                shell=tee,
                executable="/bin/bash" if tee else None,
            )
            outputs.append(result.stdout)
            if not censor_:
                options.dprint(result.stdout)
        if capture_output_:
            return outputs

    return impl


def intercept_errors(
    patterns: ErrorPatterns = {},
    *,
    quiet: bool = False,
    suppress: bool = False,
) -> Callable[[F], F]:
    def decorate(fn: F) -> F:
        @wraps(fn)
        def wrapped(
            *args: Any,
            quiet_: bool = False,
            suppress_: bool = False,
            intercept_errors_options_: Optional[GlobalOptions] = None,
            **kwargs: Any,
        ) -> Any:

            options = intercept_errors_options_
            if not options:
                # Ideally we will never need to access click at this level and
                # will instead always pass in options. This is for backward
                # compatibility as we refactor.
                options = click.get_current_context().find_object(GlobalOptions)

            try:
                return fn(*args, **kwargs)
            except CalledProcessError as err:
                message = err.stderr or ""
                raise_if_match(patterns, message)
                if not (quiet or quiet_):
                    sys.stderr.write(message)
                else:
                    options.dprint(message)
                if suppress or suppress_:
                    raise SuppressedError(err) from err
                else:
                    raise FailedSubprocessError(err) from err

        return cast(F, wrapped)

    return decorate


def loses_interactivity(fn: F) -> F:
    @click.pass_context
    @wraps(fn)
    def wrapped(context: click.Context, *args: Any, **kwargs: Any) -> Any:
        if (resource := kwargs.get("resource")) :
            saml_client = SAMLClientFactory.create_saml_client(
                resource, context.find_object(GlobalOptions)
            )
            saml_client.ensure_session()
        return context.invoke(fn, *args, **kwargs)

    return cast(F, require_login(wrapped))


def skip_analytics(fn: F) -> F:
    @click.pass_context
    @wraps(fn)
    def wrapped(context: click.Context, *args: Any, **kwargs: Any) -> Any:
        options = context.ensure_object(GlobalOptions)
        options.disable_analytics = True
        return context.invoke(fn, *args, **kwargs)

    return cast(F, wrapped)


def require_login(fn: F) -> F:
    @click.pass_context
    @wraps(fn)
    def wrapped(context: click.Context, *args: Any, **kwargs: Any) -> Any:
        if not Config.is_logged_in():
            raise CliError("Please run `sym login` first")
        return context.invoke(fn, *args, **kwargs)

    return cast(F, wrapped)



from contextlib import contextmanager
from pathlib import Path
from typing import Callable, ContextManager, Iterator

import boto3
import click
import pytest
from _pytest.monkeypatch import MonkeyPatch
from botocore.stub import Stubber
from sym.shared.cli.helpers.envvar_option import reset_used
from sym.shared.cli.tests.conftest import *  # noqa

from sym.cli.helpers import boto
from sym.cli.helpers.config import Config, init
from sym.cli.helpers.global_options import GlobalOptions
from sym.cli.helpers.sym_group import SymGroup
from sym.cli.saml_clients.aws_okta import AwsOkta
from sym.cli.saml_clients.aws_profile import AwsProfile
from sym.cli.saml_clients.saml_client import SAMLClient
from sym.cli.sym import sym as click_command
from sym.cli.tests.helpers.sandbox import Sandbox

CustomOrgFixture = Callable[[str], ContextManager[None]]


@pytest.fixture
def sandbox(tmp_path: Path) -> Sandbox:
    return Sandbox(tmp_path)


@pytest.fixture
def click_context(sandbox):
    with sandbox.push_xdg_config_home():
        Config.instance()["org"] = "sym"
        Config.instance()["email"] = "y@symops.io"
        sandbox.create_binary(f"bin/{AwsOkta.binary}")
        with sandbox.push_exec_path():
            with click.Context(click_command) as ctx:
                ctx.ensure_object(GlobalOptions)
                yield ctx


@pytest.fixture
def click_setup(sandbox: Sandbox, wrapped_cli_runner):
    @contextmanager
    def context(set_org=True, set_client=True):
        runner = wrapped_cli_runner
        with runner.isolated_filesystem():
            with sandbox.setup(set_org=set_org, set_client=set_client):
                yield runner
        reset_used()

    return context


@pytest.fixture
def no_click_setup(sandbox: Sandbox):
    """no_click_setup includes the same functionality as
    click_setup but without loading any Click configuration
    """

    @contextmanager
    def context(set_org=True, set_client=True):
        with sandbox.setup(set_org=set_org, set_client=set_client):
            yield
        reset_used()

    return context


@pytest.fixture(autouse=True)
def patch_is_setup(monkeypatch: MonkeyPatch):
    monkeypatch.setattr(SAMLClient, "check_is_setup", lambda self: ...)


@pytest.fixture
def custom_org(monkeypatch: MonkeyPatch) -> CustomOrgFixture:
    @contextmanager
    def custom_org(org: str) -> Iterator[None]:
        with monkeypatch.context() as mp:
            mp.setattr(Config, "get_org", classmethod(lambda cls: org))
            yield

    return custom_org


@pytest.fixture
def saml_client(sandbox: Sandbox, monkeypatch: MonkeyPatch, creds_env):
    def get_creds(self):
        return dict(creds_env)

    monkeypatch.setattr(AwsOkta, "get_creds", get_creds)

    def profile_matches_caller_identity(self):
        return True

    monkeypatch.setattr(
        AwsOkta, "_profile_matches_caller_identity", profile_matches_caller_identity
    )

    sandbox.create_binary(f"bin/{AwsOkta.binary}")
    with sandbox.push_exec_path():
        return AwsOkta("test", options=GlobalOptions(debug=False))


@pytest.fixture
def ssm_bins(sandbox: Sandbox):
    for binary in ["aws", "session-manager-plugin", "ssh"]:
        sandbox.create_binary(f"bin/{binary}")


@pytest.fixture
def boto_stub(monkeypatch: MonkeyPatch):
    stubs = {}

    def boto_client(_saml_client, service):
        if service in stubs:
            return stubs[service][0]

        client = boto3.client(service)
        stubber = Stubber(client)
        stubber.activate()

        stubs[service] = (client, stubber)
        return client

    monkeypatch.setattr(boto, "boto_client", boto_client)

    def get_stub(service):
        boto_client(None, service)
        return stubs[service][1]

    return get_stub


@contextmanager
def setup_context(click_command):
    with click.Context(click_command) as ctx:
        ctx.obj = GlobalOptions(saml_client_type=AwsProfile)
        yield


def empty_saml_client():
    return AwsProfile("test", options=GlobalOptions())


@pytest.fixture(autouse=True)
def cleanup(request):
    request.addfinalizer(SymGroup.reset_tees)


@pytest.fixture(autouse=True)
def init_cli():
    init("sym")



from sym.shared.cli.helpers.config import init as config_init

config_init("sym")

from sym.shared.cli.helpers.init import sym_init

from .commands import import_all as command_init
from .commands.sym import sym

command_init()
sym_init()

if __name__ == "__main__":
    sym()



from contextlib import contextmanager
from typing import Optional

from sym.shared.cli.helpers.config.base import ConfigBase
from sym.shared.cli.tests.helpers.sandbox import Sandbox as SharedSandbox

from sym.cli.helpers.config import Config
from sym.cli.saml_clients.aws_okta import AwsOkta


class Sandbox(SharedSandbox):
    def reset_config(self):
        ConfigBase.reset()
        Config.reset()

    @contextmanager
    def setup(self, set_org: Optional[bool] = True, set_client: Optional[bool] = True):
        with self.push_xdg_config_home():
            if set_client:
                self.create_binary(f"bin/{AwsOkta.binary}")
            with self.push_exec_path():
                if set_org:
                    Config.instance()["org"] = "sym"
                    Config.instance()["email"] = "y@symops.io"
                yield



from unittest.mock import patch

import pytest
from sym.shared.cli.helpers.contexts import push_env

from sym.cli.errors import InvalidResource, UnknownError
from sym.cli.sym import sym as click_command
from sym.cli.version import __version__


def test_version(click_setup):
    with click_setup(set_org=False, set_client=False) as runner:
        result = runner.invoke(click_command, ["version"])
        assert result.exit_code == 0
        assert result.output == f"{__version__}\n"


def test_login(click_setup):
    with click_setup(set_org=False) as runner:
        result = runner.invoke(
            click_command, ["login", "--org", "sym", "--email", "y@symops.io"]
        )
        assert result.exit_code == 0
        assert result.output == "Sym successfully initalized!\n"


def test_resources(click_setup):
    with click_setup() as runner:
        result = runner.invoke(click_command, ["resources"])
        assert result.exit_code == 0
        assert (
            result.output
            == "test [this_is_an_alias] (Test)\ntest_euw1 (Test: EU West 1)\ntest-custom [test_custom, test_custom2] (TestCustom)\n"
        )


def test_resources_simple(click_setup):
    with click_setup() as runner:
        result = runner.invoke(click_command, ["resources", "--format=simple"])
        assert result.exit_code == 0
        assert "this_is_an_alias" in result.output


def test_exec(click_setup, saml_client):
    with click_setup() as runner:
        result = runner.invoke(click_command, ["exec", "test", "--", "aws"])
        assert result.exit_code == 0


def test_env_vars(click_setup):
    with click_setup() as runner:
        with push_env("SYM_RESOURCE", "test"):
            result = runner.invoke(click_command, ["exec", "--", "aws"])
            assert result.exit_code == 0


def test_env_vars_invalid(click_setup):
    with click_setup() as runner:
        with push_env("SYM_RESOURCE", "tesst"):
            result = runner.invoke(click_command, ["exec", "--", "aws"])
            assert result.exit_code == InvalidResource.exit_code
            assert "Invalid resource name 'tesst'" in result.output


def test_env_vars_override(click_setup):
    with click_setup() as runner:
        with push_env("SYM_RESOURCE", "invalid"):
            result = runner.invoke(click_command, ["exec", "test", "--", "true"])
            assert result.exit_code == 0


def test_env_vars_override_invalid(click_setup):
    with click_setup() as runner:
        with push_env("SYM_RESOURCE", "invalid"):
            result = runner.invoke(click_command, ["exec", "invalid2", "--", "true"])
            assert result.exit_code == InvalidResource.exit_code
            assert "Invalid resource name 'invalid'" in result.output


@patch("sym.shared.cli.helpers.updater.SymUpdater.is_local")
@patch("click.Group.invoke")
def test_unknown_error(invoke_mock, is_local_mock, click_setup):
    is_local_mock.return_value = False
    invoke_mock.side_effect = RuntimeError("foo")

    with click_setup(set_org=False, set_client=False) as runner:
        result = runner.invoke(click_command, ["version"])
        assert result.exit_code == UnknownError.exit_code
        assert "foo" in result.output


@patch("sym.shared.cli.helpers.updater.SymUpdater.is_local")
@patch("click.Group.invoke")
def test_unknown_error_debug(invoke_mock, is_local_mock, click_setup):
    is_local_mock.return_value = False
    invoke_mock.side_effect = RuntimeError("foo")

    with click_setup(set_org=False, set_client=False) as runner:
        with pytest.raises(RuntimeError):
            result = runner.invoke(
                click_command,
                ["--debug", "version"],
                catch_exceptions=False,
            )



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['cli',
 'cli.actions',
 'cli.ansible',
 'cli.ansible.connection',
 'cli.commands',
 'cli.constants',
 'cli.data',
 'cli.helpers',
 'cli.helpers.check',
 'cli.helpers.ec2',
 'cli.saml_clients',
 'cli.tests',
 'cli.tests.commands',
 'cli.tests.decorators',
 'cli.tests.helpers',
 'cli.tests.helpers.ec2',
 'cli.tests.helpers.updater',
 'cli.tests.integration',
 'cli.tests.saml_clients']

package_data = \
{'': ['*'], 'cli.tests.helpers.updater': ['responses/*']}

install_requires = \
['PyYAML>=5.3.1,<6.0.0',
 'SecretStorage>=3.2.0,<4.0.0',
 'analytics-python>=1.3.1,<2.0.0',
 'boto3>=1.16.20,<2.0.0',
 'click-option-group>=0.5.1,<0.6.0',
 'click>=7.1.2,<8.0.0',
 'colorama<0.4.4',
 'cryptography<3.4',
 'immutables>=0.14,<0.15',
 'keyring>=21.5.0,<22.0.0',
 'mistune==0.8.4',
 'policyuniverse>=1.3.2,<2.0.0',
 'portalocker>=2.0.0,<3.0.0',
 'python-dateutil>=2.8.1,<3.0.0',
 'requests>=2.25,<3.0',
 'semver>=2.13.0,<3.0.0',
 'sentry-sdk>=0.19.3,<0.20.0',
 'sym-shared-cli==0.2.0',
 'validators>=0.18.1,<0.19.0']

entry_points = \
{'console_scripts': ['sym = sym.cli.sym:sym']}

setup_kwargs = {
    'name': 'sym-cli',
    'version': '0.2.5',
    'description': "Sym's Official CLI for Users",
    'long_description': '# sym-cli\n\nThis is the official CLI for [Sym](https://symops.com/) Users. Check out the docs [here](https://docs.symops.com/docs/install-sym-cli).\n',
    'author': 'SymOps, Inc.',
    'author_email': 'pypi@symops.io',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://symops.com/',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)



from textwrap import dedent
from typing import Sequence

import click

from sym.cli.decorators import command_require_bins, loses_interactivity, require_login
from sym.cli.helpers.global_options import GlobalOptions
from sym.cli.helpers.options import resource_argument
from sym.cli.helpers.ssh import get_ssh_user, start_ssh_tunnel
from sym.cli.saml_clients.saml_client_factory import SAMLClientFactory

from .sym import sym


def ssh_tunnel_help():
    try:
        ssh_user = get_ssh_user()
    except KeyError:
        ssh_user = "ubuntu"

    HELP = dedent(
        f"""
        Run a command that requires SSH connectivity (such as `scp`) with a Sym SSH Tunnel.

        sym ssh-tunnel RESOURCE PROGRAM OPTIONS

        Note that you must manually specify both the destination instance
        and your SSH user (usually {ssh_user}) in the OPTIONS.

        For example, to use `scp` to copy a remote file to your machine:

        \b
        sym ssh-tunnel prod scp {ssh_user}@i-0647ba4f8187ac121:~/file.txt file.txt

        If this command fails, try to first `sym ssh` into the instance, then try again.

        https://docs.symops.com/docs/ssh-tunnel
    """
    )


@sym.command(short_help="Run a command with a Sym SSH Tunnel", help=ssh_tunnel_help())
@resource_argument
@click.argument("program")
@click.argument("opts", nargs=-1, required=False)
@click.make_pass_decorator(GlobalOptions)
@command_require_bins("aws", "session-manager-plugin", "ssh")
@require_login
@loses_interactivity
def ssh_tunnel(
    options: GlobalOptions,
    resource: str,
    program: str,
    opts: Sequence[str],
) -> None:
    client = SAMLClientFactory.create_saml_client(resource, options)
    client.send_analytics_event()

    start_ssh_tunnel(client, program, opts)



from typing import Sequence

import click
from click import Argument, BadParameter, Option
from sym.shared.cli.errors import (  # noqa
    BotoError,
    CliError,
    CliErrorWithHint,
    FailedSubprocessError,
    OfflineError,
    SuppressedError,
    UnknownError,
    WrappedSubprocessError,
    raise_if_match,
)
from sym.shared.cli.helpers.keywords_to_options import keywords_to_options
from sym.shared.cli.helpers.util import get_param


class UnavailableResourceError(CliErrorWithHint):
    def __init__(self) -> None:
        super().__init__(
            "You don't have permission to access the Sym resource you requested.",
            "Request approval and then try again.",
        )


class ResourceNotSetup(CliErrorWithHint):
    def __init__(self) -> None:
        super().__init__(
            "The Sym resource you requested is not set up properly.",
            "Contact your Sym administrator.",
            report=True,
        )


class TargetNotConnected(CliErrorWithHint):
    def __init__(self) -> None:
        super().__init__(
            "The instance you tried to SSH into is not connected to AWS Session Manager.",
            "Ask your Sym administrator if they've set up Session Manager.",
        )


class AccessDenied(CliErrorWithHint):
    def __init__(self) -> None:
        super().__init__(
            "You don't have access to connect to this instance.",
            "Have you requested access?",
        )


class InstanceNotFound(CliError):
    def __init__(self, instance) -> None:
        super().__init__(f"Could not find instance {instance}")


class SAMLClientNotFound(CliError):
    def __init__(self) -> None:
        super().__init__(
            "No valid SAML client found in PATH. Supported clients are listed in `sym --help`."
        )


class MissingPublicKey(WrappedSubprocessError):
    def __init__(self, wrapped, user) -> None:
        super().__init__(wrapped, f"Does the user ({user}) exist on the instance?")


class SamlClientNotSetup(CliErrorWithHint):
    def __init__(self) -> None:
        super().__init__(
            "Your SAML client is not set up.",
            "Consult the docs for your client.",
        )


class ExpiredCredentials(CliErrorWithHint):
    def __init__(self) -> None:
        super().__init__(
            "Your AWS credentials have expired.",
            "\n".join(
                [
                    "Try running `sym write-creds` again, or run your command with SYM_SESSION_LENGTH=60.",
                    "For more details, see: https://docs.symops.com/docs/common-issues-sym-cli#error-your-aws-credentials-have-expired",
                ]
            ),
        )


class MissingResource(CliErrorWithHint, BadParameter):
    def __init__(
        self,
        profiles: Sequence[str],
        resource_name="resource",
    ) -> None:
        super().__init__(
            "You must supply a resource!",
            self.__class__.gen_hint(resource_name, profiles),
        )

    @classmethod
    def gen_hint(cls, resource_name, profiles) -> str:
        return "\n".join(
            [
                click.style(
                    f"These are the {resource_name}s available to you:",
                    fg="white",
                    reset=False,
                ),
                *[f"  - {key}" for key in profiles],
            ]
        )


class InvalidResource(CliErrorWithHint, BadParameter, KeyError):
    def __init__(
        self,
        resource: str,
        profiles: Sequence[str],
        resource_name="resource",
    ) -> None:
        super().__init__(
            f"Invalid {resource_name} name '{resource}'",
            self.gen_hints(resource, resource_name, profiles),
        )

    def gen_hints(self, resource, resource_name, profiles) -> Sequence[str]:
        hints = [
            "\n".join(
                [
                    f"Has your Sym Implementer set up {resource} yet?",
                    MissingResource.gen_hint(resource_name, profiles),
                ]
            )
        ]
        if (ctx := click.get_current_context()) :
            if ctx.command.params[0].name == resource_name:
                args = [
                    v
                    for k, v in ctx.params.items()
                    if isinstance(get_param(ctx.command, k), Argument)
                ]
                if len(args) == 1:
                    return hints
                opts = {
                    k: v
                    for k, v in ctx.params.items()
                    if isinstance(get_param(ctx.command, k), Option)
                    and get_param(ctx.command, k).get_default(ctx) != v
                }
                cmd = " ".join(
                    [
                        *keywords_to_options([opts]),
                        (
                            click.style(profiles[0], fg="magenta", reset=False)
                            + click.style("", fg="white", reset=False)
                        ),
                        *keywords_to_options(args),
                        *ctx.args,
                    ]
                )
                hints.insert(
                    0,
                    "\n".join(
                        [
                            "Did you forget to pass a RESOURCE as the first argument?",
                            click.style(
                                f"e.g. `{ctx.command_path} {cmd}`",
                                fg="white",
                            ),
                        ]
                    ),
                )

        return hints



import click
from sym.shared.cli.helpers.updater import SymUpdater

from sym.cli.helpers.global_options import GlobalOptions

from .sym import sym


@sym.command(short_help="Update the Sym CLI")
@click.make_pass_decorator(GlobalOptions)
def update(options: GlobalOptions) -> None:
    SymUpdater(debug=options.debug).manual_update()



import os
import random
from contextlib import contextmanager

import boto3
import pytest
from expects import *

from sym.cli.sym import sym as click_command
from sym.cli.tests.matchers import succeed


def gen_instances():
    if not os.getenv("SYM_INTEGRATION"):
        yield "i-xxx"
        return

    ec2 = boto3.client("ec2")
    paginator = ec2.get_paginator("describe_instances")
    for response in paginator.paginate(
        Filters=[{"Name": "tag:CLITest", "Values": ["integration"]}]
    ):
        for reservation in response["Reservations"]:
            for instance in reservation["Instances"]:
                yield instance["InstanceId"]


@pytest.fixture
def integration_runner(capfdbinary, sandbox, wrapped_cli_runner):
    @contextmanager
    def context():
        runner = wrapped_cli_runner
        with sandbox.push_xdg_config_home():

            def run(*args):
                result = runner.invoke(click_command, args, catch_exceptions=False)
                cap = capfdbinary.readouterr()
                result.stdout_bytes = cap.out
                result.stderr_bytes = cap.err

                expect(result).to(succeed())
                return result

            yield run

    return context


def pytest_addoption(parser):
    parser.addoption("--email", default="ci@symops.io")
    parser.addoption("--org", default="sym")
    parser.addoption("--instance", default=random.choice(list(gen_instances())))
    parser.addoption("--resource", default="test")



from sym.cli.helpers.config import Config
from sym.cli.helpers.params import get_aws_saml_url, get_profile
from sym.cli.tests.helpers.sandbox import Sandbox


def test_profile_aliases(sandbox: Sandbox):
    with sandbox.push_xdg_config_home():
        Config.instance()["org"] = "launchdarkly"
        assert get_profile("intuit_production") is not None


def test_get_aws_saml_url_alias(sandbox: Sandbox):
    with sandbox.push_xdg_config_home():
        Config.instance()["org"] = "launchdarkly"
        assert get_aws_saml_url("intuit_production") is not None
